==> add-content-workflow-angularjs-1.5.19.tgz: package/source/app/add-content-search-selection/add-content-search-selection.component.ts <==
export default class AddContentSearchSelectionComponent {
    workflow: any;

    static config = {
        selector: 'addContentSearchSelection',
        template: `
        <div layout="column" class="add-content-workflow__tag-selection">
            <label class="add-content-workflow__add flux-text--title" ng-if="$ctrl.workflow.currentStep === 'source'">Add to search</label>
            <label class="flux-text--title" ng-if="$ctrl.workflow.currentStep === 'details'">{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--tags-label')}}</label>
            <div class="add-content-workflow__tag-selection--tag-container">
                <div>
                    <md-button 
                        class="mw-button mw-button--has-icon" 
                        ng-click="$ctrl.showSearchSelectModal($event)" 
                        ng-disabled="$ctrl.workflow.loading || $ctrl.workflow.loadingSearches || $ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"
                        style="margin: 8px 0">
                        <md-progress-circular ng-if="$ctrl.workflow.loadingSearches"
                            md-diameter="16px"
                            style="margin: 8px auto"></md-progress-circular>
                        <mw-icon ng-if="!$ctrl.workflow.loadingSearches" svg-icon="content:ic_add_circle_outline_24px"></mw-icon>
                        <span ng-if="!$ctrl.workflow.loadingSearches">
                        SELECT INPUTS
                        </span>
                    </md-button>
                </div>
                <md-chips readonly="true" md-removable="true" ng-model="$ctrl.workflow.documentSearches" md-on-remove="$ctrl.deselectSearch($chip)">
                    <md-chip-template>
                    {{ $chip.substring(0,25) }}<span ng-if="$chip.length > 25">...</span>
                        <md-tooltip ng-if="$chip.length > 25">{{ $chip }}</md-tooltip>
                    </md-chip-template>
                </md-chips>
            </div>
        </div>
        `,
        controller: AddContentSearchSelectionComponent,
        bindings: {
            workflow: '<'
        },
        
    };
    constructor(
        private $mdDialog,
        private AddContentTranslate,
        
    ) {
    }
    deselectSearch = (display) => {
        let searches = this.workflow.searches;
        for(let i = 0; i < searches.length; i++){
            if(searches[i].display === display){
                searches[i].selected = false
                return
            }
        }
      };
          
      showSearchSelectModal = (event) => {
        const parent = angular.element(document.getElementsByClassName('md-dialog-container')[0]);

        this.$mdDialog.show({
            parent,
            multiple: true,
            autoWrap: false,
            bindToController: true,
            fullscreen: true,
            targetEvent: event,
            locals: {
                inputs: angular.copy(this.workflow.searches),
                workflow: this.workflow
            },
            template: `
                <md-dialog class="mw-mini-modal mw-mini-modal--maximized" aria-label="" layout="column">
                    <search-selector-dialog workflow="$ctrl.workflow" class="mw-mini-modal-wrapper" inputs="$ctrl.inputs" layout="column"></search-selector-dialog>
                </md-dialog>
            `,
            controller: 'MwMiniModalDialogController',
            controllerAs: '$ctrl',
        })
            .then(
                (inputs) => {
                    this.workflow.searches = inputs;
                    this.workflow.documentSearches = this.workflow.searches
                    .filter((search)=> search.selected)
                    .map((search)=>{
                        return search.display
                    })
                }
            )
            .catch(error => {
                if (error) {
                    console.error('Error applying searches to add content', error);
                }
            });
    };
    cancel() {
        this.$mdDialog.cancel();
    }
}

==> add-content-workflow-angularjs-1.5.21.tgz: package/source/app/add-content-search-selection/add-content-search-selection.component.ts <==
export default class AddContentSearchSelectionComponent {
    workflow: any;

    static config = {
        selector: 'addContentSearchSelection',
        template: `
        <div layout="column" class="add-content-workflow__tag-selection">
            <label class="add-content-workflow__add flux-text--title" ng-if="$ctrl.workflow.currentStep === 'source'">Add to search</label>
            <label class="flux-text--title" ng-if="$ctrl.workflow.currentStep === 'details'">Add to search</label>
            <div class="add-content-workflow__tag-selection--tag-container">
                <div>
                    <md-button 
                        class="mw-button mw-button--has-icon" 
                        ng-click="$ctrl.showSearchSelectModal($event)" 
                        ng-disabled="$ctrl.workflow.loading || $ctrl.workflow.loadingSearches || $ctrl.workflow.savingAddContent || $ctrl.workflow.skipChecked"
                        style="margin: 8px 0">
                        <md-progress-circular ng-if="$ctrl.workflow.loadingSearches"
                            md-diameter="16px"
                            style="margin: 8px auto"></md-progress-circular>
                        <mw-icon ng-if="!$ctrl.workflow.loadingSearches" svg-icon="content:ic_add_circle_outline_24px"></mw-icon>
                        <span ng-if="!$ctrl.workflow.loadingSearches">
                        SELECT INPUTS
                        </span>
                    </md-button>
                </div>
                <md-chips readonly="true" md-removable="true" ng-model="$ctrl.workflow.documentSearches" md-on-remove="$ctrl.deselectSearch($chip)">
                    <md-chip-template>
                    {{ $chip.substring(0,25) }}<span ng-if="$chip.length > 25">...</span>
                        <md-tooltip ng-if="$chip.length > 25">{{ $chip }}</md-tooltip>
                    </md-chip-template>
                </md-chips>
            </div>
        </div>
        `,
        controller: AddContentSearchSelectionComponent,
        bindings: {
            workflow: '<'
        },
        
    };
    constructor(
        private $mdDialog,
        private AddContentTranslate,
        
    ) {
    }
    deselectSearch = (display) => {
        let searches = this.workflow.searches;
        for(let i = 0; i < searches.length; i++){
            if(searches[i].display === display){
                searches[i].selected = false
                return
            }
        }
      };
          
      showSearchSelectModal = (event) => {
        const parent = angular.element(document.getElementsByClassName('md-dialog-container')[0]);

        this.$mdDialog.show({
            parent,
            multiple: true,
            autoWrap: false,
            bindToController: true,
            fullscreen: true,
            targetEvent: event,
            locals: {
                inputs: angular.copy(this.workflow.searches),
                workflow: this.workflow
            },
            template: `
                <md-dialog class="mw-mini-modal mw-mini-modal--maximized" aria-label="" layout="column">
                    <search-selector-dialog workflow="$ctrl.workflow" class="mw-mini-modal-wrapper" inputs="$ctrl.inputs" layout="column"></search-selector-dialog>
                </md-dialog>
            `,
            controller: 'MwMiniModalDialogController',
            controllerAs: '$ctrl',
        })
            .then(
                (inputs) => {
                    this.workflow.searches = inputs;
                    this.workflow.documentSearches = this.workflow.searches
                    .filter((search)=> search.selected)
                    .map((search)=>{
                        return search.display
                    })
                }
            )
            .catch(error => {
                if (error) {
                    console.error('Error applying searches to add content', error);
                }
            });
    };
    cancel() {
        this.$mdDialog.cancel();
    }
}
